#
# spec file for package openxcom
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           openxcom
Version:        1.0.0.1552426261.8a4b13d65
Release:        bp153.1.19
Summary:        An open source reimplementation of the original X-Com game
License:        GPL-3.0-only
Group:          Amusements/Games/Strategy/Turn Based
URL:            http://openxcom.org/
Source:         OpenXcom-%{version}.tar.xz
BuildRequires:  Mesa-devel
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  docbook2X
BuildRequires:  dos2unix
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  xmlto
BuildRequires:  pkgconfig(SDL_gfx)
BuildRequires:  pkgconfig(SDL_image)
BuildRequires:  pkgconfig(SDL_mixer)
BuildRequires:  pkgconfig(sdl)
BuildRequires:  pkgconfig(yaml-cpp) >= 0.5

%description
OpenXcom is an open-source clone of the original UFO: Enemy Unknown
(X-Com: UFO Defense in USA), licensed under the GPL and written in C++ / SDL.

The goal of the project is to bring back the tried and true feel of the original
with none of the issues. All the same graphics, sound and gameplay with a brand
new codebase written from scratch.

User is required to have original gamedata (possible to obtain from e.g. Steam)
installed to ~/.local/share/openxcom/data/

%package doc
Summary:        Documentation files for %{name}
Group:          Amusements/Games/Strategy/Turn Based
Requires:       %{name} = %{version}

%description doc
Documentation files for %{name} game.

%prep
%setup -q -n OpenXcom-%{version}

chmod -x LICENSE.txt
sed -i \
	-e 's:HTML_TIMESTAMP         = YES:HTML_TIMESTAMP         = NO:g' \
	docs/Doxyfile.in
dos2unix *.txt

%build
autoreconf -fvi
%configure \
	--disable-werror \
	--disable-silent-rules \
	--with-docs --docdir="%{_docdir}/%{name}"
make %{?_smp_mflags}

%install
%make_install
pushd %{buildroot}%{_datadir}/pixmaps/
ln -s openxcom_wide.svg openxcom.svg
popd
%fdupes %{buildroot}%{_datadir}

%files
%license LICENSE.txt
%doc README.md CHANGELOG.txt
%{_datadir}/applications/openxcom.desktop
%{_mandir}/man6/openxcom.6%{?ext_man}
%{_datadir}/pixmaps/*
%{_datadir}/%{name}/
%{_docdir}/%{name}/*.txt
%{_bindir}/%{name}
%dir %{_docdir}/%{name}
%exclude %{_docdir}/%{name}/html/

%files doc
%dir %{_docdir}/%{name}
%dir %{_docdir}/%{name}/html
%{_docdir}/%{name}/html/*

%changelog
* Sat Mar 23 2019 tchvatal@suse.com
- Switch to github service as there was n o release since 2014
  and there are simply too many fixes in the git repository
- Update to version 1.0.0.1552426261.8a4b13d65:
  * Update links
  * Check if OXCE is required when enabling mods
  * Don't replenish empty medikits after reload
  * Fix language loading to properly default to en-US when translations are missing. Prioritize untranslated text over incorrect text.
  * Correctly drop units on the ground
  * Fix handling a mix of unconscious and MIA units
  * Fix handling of unconscious ignored units
  * Fix ignored units making it through to the next stage
- Remove upstream patches:
  * openxcom-math.patch
  * openxcom-abs.patch
* Wed Feb 14 2018 tchvatal@suse.com
- Add patch fixing build with gcc7 by explicitly stating math
  includes:
  * openxcom-math.patch
* Fri Jun 17 2016 tchvatal@suse.com
- Add patch fixing gcc6 build bnc#985174:
  * openxcom-abs.patch
* Mon Mar 28 2016 tchvatal@suse.com
- Enable verbose build
- Do not hardcode manpage suffix
* Thu Jul 17 2014 tchvatal@suse.com
- Fix collisions between -doc and regular pkg.
* Tue Jul  8 2014 tchvatal@suse.com
- Install license and other docs.
* Fri Jul  4 2014 tchvatal@suse.com
- Fix Sources url as it aint woring at all.
* Sat Jun 14 2014 mailaender@opensuse.org
- Update to version 1.0.0
* Mon May 20 2013 tchvatal@suse.com
- Version bump to 0.9.0: major update with almost full possible
  gameplay.
* Mon Nov 12 2012 tchvatal@suse.com
- Version bump to 0.4.5. Fix various warnings from obs.
* Sun Oct 28 2012 tchvatal@suse.com
- Bump the version to 0.4.5_pre20121028 as upstream release is
  broken and it is fixed in git.
* Sat Oct 27 2012 tchvatal@suse.com
- Bump the version to 0.4
* Tue Nov 22 2011 tchvatal@suse.com
- Initial commit of openxcom.
